@@ -803,8 +803,12 @@ sha1_handle_second_client_response (DBusAuth         *auth,
                                           auth->desired_identity))
     goto out_3;
 
-  /* Copy process ID from the socket credentials if it's there
+  /* Copy process ID (and PID FD) from the socket credentials if it's there
    */
+  if (!_dbus_credentials_add_credential (auth->authorized_identity,
+                                         DBUS_CREDENTIAL_UNIX_PROCESS_FD,
+                                         auth->credentials))
+    goto out_3;
   if (!_dbus_credentials_add_credential (auth->authorized_identity,
                                          DBUS_CREDENTIAL_UNIX_PROCESS_ID,
                                          auth->credentials))
@@ -1187,6 +1191,11 @@ handle_server_data_external_mech (DBusAuth         *auth,
 
       /* also copy misc process info from the socket credentials
        */
+      if (!_dbus_credentials_add_credential (auth->authorized_identity,
+                                             DBUS_CREDENTIAL_UNIX_PROCESS_FD,
+                                             auth->credentials))
+        return FALSE;
+
       if (!_dbus_credentials_add_credential (auth->authorized_identity,
                                              DBUS_CREDENTIAL_UNIX_PROCESS_ID,
                                              auth->credentials))
@@ -1304,8 +1313,13 @@ handle_server_data_anonymous_mech (DBusAuth         *auth,
   /* We want to be anonymous (clear in case some other protocol got midway through I guess) */
   _dbus_credentials_clear (auth->desired_identity);
 
-  /* Copy process ID from the socket credentials
+  /* Copy process ID (and PID FD) from the socket credentials
    */
+  if (!_dbus_credentials_add_credential (auth->authorized_identity,
+                                         DBUS_CREDENTIAL_UNIX_PROCESS_FD,
+                                         auth->credentials))
+    return FALSE;
+
   if (!_dbus_credentials_add_credential (auth->authorized_identity,
                                          DBUS_CREDENTIAL_UNIX_PROCESS_ID,
                                          auth->credentials))
