@@ -3,8 +3,10 @@
  *
  * Copyright (C) 2003, 2004  Red Hat Inc.
  *
+ * SPDX-License-Identifier: AFL-2.1 OR GPL-2.0-or-later
+ *
  * Licensed under the Academic Free License version 2.1
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -14,7 +16,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -1023,7 +1025,7 @@ _dbus_keyring_get_hex_key (DBusKeyring       *keyring,
 #include <stdio.h>
 
 dbus_bool_t
-_dbus_keyring_test (void)
+_dbus_keyring_test (const char *test_data_dir _DBUS_GNUC_UNUSED)
 {
   DBusString context;
   DBusKeyring *ring1;
